@@ -29,6 +29,7 @@ from transformers import (
 )
 from transformers.testing_utils import (
     cleanup,
+    is_flaky,
     require_torch,
     require_torch_sdpa,
     slow,
@@ -373,6 +374,11 @@ class SmolVLMForConditionalGenerationModelTest(GenerationTesterMixin, ModelTeste
     def test_prompt_lookup_decoding_matches_greedy_search(self):
         pass
 
+    @pytest.mark.generate
+    @is_flaky(description="TODO: check why flaky")
+    def test_generate_methods_with_logits_to_keep(self):
+        super().test_generate_methods_with_logits_to_keep()
+
     @unittest.skip(reason=" FlashAttention only support fp16 and bf16 data type")
     def test_flash_attn_2_fp32_ln(self):
         pass
